@@ -16,16 +16,16 @@ from datetime import datetime
 from typing import List
 
 from .literals import (
-    AttackLayer,
-    AttackPropertyIdentifier,
-    AutoRenew,
-    ProactiveEngagementStatus,
-    ProtectedResourceType,
-    ProtectionGroupAggregation,
-    ProtectionGroupPattern,
-    SubResourceType,
-    SubscriptionState,
-    Unit,
+    AttackLayerType,
+    AttackPropertyIdentifierType,
+    AutoRenewType,
+    ProactiveEngagementStatusType,
+    ProtectedResourceTypeType,
+    ProtectionGroupAggregationType,
+    ProtectionGroupPatternType,
+    SubResourceTypeType,
+    SubscriptionStateType,
+    UnitType,
 )
 
 if sys.version_info >= (3, 8):
@@ -94,10 +94,10 @@ AttackDetailTypeDef = TypedDict(
 AttackPropertyTypeDef = TypedDict(
     "AttackPropertyTypeDef",
     {
-        "AttackLayer": AttackLayer,
-        "AttackPropertyIdentifier": AttackPropertyIdentifier,
+        "AttackLayer": AttackLayerType,
+        "AttackPropertyIdentifier": AttackPropertyIdentifierType,
         "TopContributors": List["ContributorTypeDef"],
-        "Unit": Unit,
+        "Unit": UnitType,
         "Total": int,
     },
     total=False,
@@ -256,7 +256,7 @@ class EmergencyContactTypeDef(_RequiredEmergencyContactTypeDef, _OptionalEmergen
 GetSubscriptionStateResponseTypeDef = TypedDict(
     "GetSubscriptionStateResponseTypeDef",
     {
-        "SubscriptionState": SubscriptionState,
+        "SubscriptionState": SubscriptionStateType,
     },
 )
 
@@ -382,15 +382,15 @@ _RequiredProtectionGroupTypeDef = TypedDict(
     "_RequiredProtectionGroupTypeDef",
     {
         "ProtectionGroupId": str,
-        "Aggregation": ProtectionGroupAggregation,
-        "Pattern": ProtectionGroupPattern,
+        "Aggregation": ProtectionGroupAggregationType,
+        "Pattern": ProtectionGroupPatternType,
         "Members": List[str],
     },
 )
 _OptionalProtectionGroupTypeDef = TypedDict(
     "_OptionalProtectionGroupTypeDef",
     {
-        "ResourceType": ProtectedResourceType,
+        "ResourceType": ProtectedResourceTypeType,
         "ProtectionGroupArn": str,
     },
     total=False,
@@ -423,7 +423,7 @@ ProtectionTypeDef = TypedDict(
 SubResourceSummaryTypeDef = TypedDict(
     "SubResourceSummaryTypeDef",
     {
-        "Type": SubResourceType,
+        "Type": SubResourceTypeType,
         "Id": str,
         "AttackVectors": List["SummarizedAttackVectorTypeDef"],
         "Counters": List["SummarizedCounterTypeDef"],
@@ -451,9 +451,9 @@ _OptionalSubscriptionTypeDef = TypedDict(
         "StartTime": datetime,
         "EndTime": datetime,
         "TimeCommitmentInSeconds": int,
-        "AutoRenew": AutoRenew,
+        "AutoRenew": AutoRenewType,
         "Limits": List["LimitTypeDef"],
-        "ProactiveEngagementStatus": ProactiveEngagementStatus,
+        "ProactiveEngagementStatus": ProactiveEngagementStatusType,
         "SubscriptionArn": str,
     },
     total=False,
